@@ -1,5 +1,4 @@
 use v6;
-use Panda::Common;
 use Panda::Builder;
 use Shell::Command;
 use LibraryMake;
@@ -13,7 +12,9 @@ class Build is Panda::Builder {
             or die "\nPlease install the Filter::Simple Perl 5 module!\n";
 
         my %vars = get-vars($dir);
-        %vars<p5helper> = $*VM.platform-library-name('p5helper'.IO);
+        %vars<p5helper> = %vars<DESTDIR>.IO.child('resources').child('libraries')
+            .child($*VM.platform-library-name('p5helper'.IO)).Str;
+        %vars<perlopts> = run(<perl -MExtUtils::Embed -e ccopts -e ldopts>, :out).out.lines.join('');
         mkdir "$dir/resources" unless "$dir/resources".IO.e;
         mkdir "$dir/resources/libraries" unless "$dir/resources/libraries".IO.e;
         process-makefile($dir, %vars);
